@@ -18,7 +18,7 @@ class ftpUtil:
     __url_head="http://home.hddly.cn:90/stud/"
     __mutil= mysqlUtil()
 
-    def putfile_project(self, local_path, prj_id, stud_id, no_file,desc):
+    def putfile_project(self, local_path, prj_id, stud_id, no_file,fdesc):
         # # 要传输文件的路径
         # filepath = "./myname.jpg"
         # # 上传后的传输文件的文件名
@@ -58,7 +58,7 @@ class ftpUtil:
             # item['filename'] = local_path
             # item['url'] = self.__url_head+remote_file
             # item['stud'] = stud
-            self.__mutil.sftp_file_ins(local_path, self.__url_head +prj +'/'+ remote_file, stud,desc,fsize,duration,ftype)
+            self.__mutil.sftp_file_ins(local_path, self.__url_head +prj +'/'+ remote_file, stud,fdesc,fsize,duration,ftype)
         except Exception as ex:
             print("日志记录出现如下异常%s" % ex)
 
