@@ -10,10 +10,11 @@ class mysqlUtil:
     __mysql_ip = 'home.hddly.cn'
     __port = 53306
     __db = 'test'
+
     def __init__(self):
         self.OpenDB(self.__db)
 
-    def OpenDB(self,dbname):
+    def OpenDB(self, dbname):
         self.__db = dbname
         self.__mysql_ip = 'home.hddly.cn'
         self.__port = 53306
@@ -24,7 +25,7 @@ class mysqlUtil:
                                                     self.__port,
                                                     self.__db))
 
-    def OpenDBYgxy(self,dbname):
+    def OpenDBYgxy(self, dbname):
         self.__db = dbname
         self.__mysql_ip = '10.255.10.51'
         self.__port = 3306
@@ -34,7 +35,8 @@ class mysqlUtil:
                                                     self.__mysql_ip,
                                                     self.__port,
                                                     self.__db))
-    def OpenDBAny(self,ip,port,dbname):
+
+    def OpenDBAny(self, ip, port, dbname):
         self.__db = dbname
         self.__mysql_ip = ip
         self.__port = port
@@ -44,6 +46,7 @@ class mysqlUtil:
                                                     self.__mysql_ip,
                                                     self.__port,
                                                     self.__db))
+
     # 查询mysql数据库
     def query(self, sql):
         df = pd.read_sql_query(sql, self.engine)
@@ -63,12 +66,14 @@ class mysqlUtil:
             return results[0]
         return None
 
-    #添加上传文件记录
-    def sftp_file_ins(self,filename,url,stud,desc,fsize,duration,ftype):
+    # 添加上传文件记录
+    def sftp_file_ins(self, filename, url, stud, fdesc, fsize, duration, ftype):
         try:
-            df = pd.DataFrame(columns=['filename','url','stud','desc','fsize','duration','ftype'])
+            df = pd.DataFrame(columns=['filename', 'url', 'stud', 'fdesc', 'fsize', 'duration', 'ftype'])
             # print(df)
-            row1=pd.DataFrame({'filename':filename,'url':url,'stud':stud,'desc':desc,'fsize':fsize,'duration':duration,'ftype':ftype}, index=[1])
+            row1 = pd.DataFrame(
+                {'filename': filename, 'url': url, 'stud': stud, 'fdesc': fdesc, 'fsize': fsize, 'duration': duration,
+                 'ftype': ftype}, index=[1])
             # print(row1)
             # df=df.append(row1,ignore_index=True)
             df = pd.concat([df, row1], ignore_index=True)  # append过时，改用concat
@@ -78,7 +83,26 @@ class mysqlUtil:
         except Exception as ex:
             print("日志记录出现如下异常%s" % ex)
 
+    # 获了上传文件记录
+    def get_file_list(self, ftype):
+        if ftype:
+            ftype = str(ftype).lower()
+            sql = 'select id,url,fdesc,fsize,duration,ftype,uptime from sftp_files where ftype="{}" order by uptime desc limit 100'.format(
+                ftype)
+        else:
+            ftype = ".mp4"
+            'select id,url,fdesc,fsize,duration,ftype,uptime from sftp_files where ftype="{}" order by uptime desc limit 100'.format(
+                ftype)
+        df = pd.read_sql(sql, self.engine)
+        results = json.loads(df.to_json(orient='records'))
+        if results and len(results) == 1:
+            return results[0]
+        elif results and len(results)>1:
+            return results
+        else:
+            return None
+
     def process_item(self, item, tblname):
-        data = pd.DataFrame(dict(item),index=[0])
-        data.to_sql(tblname, self.engine, if_exists='append', index=False) #'taobao_data'
-        return item
\ No newline at end of file
+        data = pd.DataFrame(dict(item), index=[0])
+        data.to_sql(tblname, self.engine, if_exists='append', index=False)  # 'taobao_data'
+        return item
